@@ -1,5 +1,5 @@
 `penalized.pls.default` <-
-function(X,y,M,ncomp=min(nrow(X)-1,ncol(X))){
+function(X,y,M,ncomp){
 
   X0<-X
 
