@@ -1,5 +1,5 @@
 `ppls.splines.cv` <-
-function(X,y,lambda=1,ncomp=NULL,degree=3,order=2,nknot=NULL,k=5,kernel=FALSE){
+function(X,y,lambda=1,ncomp=NULL,degree=3,order=2,nknot=NULL,k=5,kernel=FALSE,scale=FALSE,reduce.knots=FALSE,select=FALSE){
 
   n<-nrow(X)
 
@@ -11,7 +11,7 @@ function(X,y,lambda=1,ncomp=NULL,degree=3,order=2,nknot=NULL,k=5,kernel=FALSE){
 
   error.cv=matrix(0,length(lambda),ncomp)
 
-  all.folds <- split(1:n, rep(1:k,length=n))
+  all.folds <- split(sample(1:n), rep(1:k,length=n))
   
   for (i in seq(k)){
   
@@ -21,21 +21,25 @@ function(X,y,lambda=1,ncomp=NULL,degree=3,order=2,nknot=NULL,k=5,kernel=FALSE){
         Xtest=X[omit,,drop=FALSE]
         ytest=y[omit]
                 
-        Z<-X2s(Xtrain,Xtest,degree,nknot)
+        Z<-X2s(Xtrain,Xtest,degree,nknot,reduce.knots=reduce.knots)
 
         Ztrain=Z$Z
 
         Ztest<-Z$Ztest
 
         P<-Penalty.matrix(m=Z$sizeZ,order=order)
+        blocks=c()
+        for (b in 1:length(Z$sizeZ)){
+            blocks=c(blocks,rep(b,Z$sizeZ[b]))
+        }
     
         for (j in 1:length(lambda)){
-            penpls=penalized.pls(Ztrain,ytrain,lambda[j]*P,ncomp,kernel)
+            penpls=penalized.pls(Ztrain,ytrain,lambda[j]*P,ncomp,kernel,blocks=blocks,select=select,scale=scale)
             error.cv[j,]=error.cv[j,]+ length(ytest)*(new.penalized.pls(penpls,Ztest,ytest)$mse)
         }
   
   }
-
+  #cat(paste("cv completed \n"))
   error.cv=error.cv/n
   value1=apply(error.cv,1,min)
   lambda.opt=lambda[which.min(value1)]
